.about <- function(){
  tkmessageBox(title="MI GUI", message="Daniel Lee & Yu-Sung Su 2010", icon="info", type="ok")
}

.doc <- function(){
  browseURL("http://www.stat.columbia.edu/~yusung/mipaper.pdf")
}


.bugsReport <- function(){
  browseURL("https://r-forge.r-project.org/tracker/?atid=2972&group_id=731")
}
